from django.contrib import admin
from jumbo_product.models import Product , ProductCategory , ProductGalleryImage
from mptt.admin import MPTTModelAdmin
from .models import ProductTranslation


class ProductTranslationInline(admin.StackedInline):
    model = ProductTranslation
    extra = 0
    fields = ('language', 'name', 'short_description', 'full_description','hints')


class ProductImageInline(admin.StackedInline):
    model = ProductGalleryImage
    fields = ['title','image','status']
    extra = 1

class ProductAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("name",)}
    fieldsets = (
        (None, {
            'fields': ( 'name','slug','short_description','max_temp','hints',
                        'status','full_description','prod_categories','related_products','table_description',
                      )
        }),
        ('Advanced options', {
            'classes': ('collapse',),
            'fields': ('creator','date_create','last_modifier','date_last_modify', 'ordering')
        }),
    )
    list_display = ['__unicode__','ordering',]#'hints'
    list_editable = ['ordering',]#'hints'
    ordering = ['name',]
    inlines = [ ProductImageInline, ProductTranslationInline]


class ProductCategoryAdmin(MPTTModelAdmin):
    prepopulated_fields = {"slug": ("name",)}
    fieldsets = (
        (None, {
            'fields': ( 'name','slug','description','code','status','long_description',)
        }),
        ('Advanced options', {
            'classes': ('collapse',),
            'fields': ('creator','date_create','last_modifier','date_last_modify', 'ordering')
        }),
    )
    list_display = ['__unicode__','status','ordering']
    list_editable = ['ordering','status']


admin.site.register(ProductCategory, ProductCategoryAdmin)
admin.site.register(Product, ProductAdmin)


