from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _
from filer.fields.image import FilerImageField
from jumbo.middleware.thread_local import get_request, get_current_user
from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jumbo_i18n.models import TranslationModel, I18NModel
from jumbo.db.fields import HTMLField ,HTMLFieldTinyMCE
from polymorphic.polymorphic_model import PolymorphicModel
from .productcategories import ProductCategory
import mptt

#==============================================================================
# Product
#==============================================================================
class ProductAbstract(PolymorphicModel,DateModel, UserModel, StatusModel, OrderedModel):
    """
    A basic product for the shop
    Most of the already existing fields here should be generic enough to reside
    on the "base model" and not on an added property
    """
    name   = models.CharField(max_length=255, verbose_name=_('Name'))
    slug   = models.SlugField(verbose_name=_('Slug'), unique=True, )

    short_description = models.CharField( blank=True, null=True, max_length=150, verbose_name=_("Short description"), )
    full_description = HTMLField( blank=True, null=True, verbose_name=_("Full description"),)
    #ForeignKey Relationship
    #prod_categories = models.ManyToManyField( "ProductCategory" , blank=True, null=True, related_name="products", verbose_name=_("Product Categories"),)

    class Meta(object):
        abstract = True
        app_label = 'jumbo_product'
        verbose_name = _('Product')
        verbose_name_plural = _('Products')

    def __unicode__(self):
        return self.name

    def detail_url(self):
        return "hello"

class Product(PolymorphicModel,DateModel, UserModel, StatusModel, OrderedModel,I18NModel):

    name   = models.CharField(max_length=255, verbose_name=_('Name'))
    slug   = models.SlugField(verbose_name=_('Slug'), unique=True, )

    short_description = models.CharField( blank=True, null=True, max_length=150, verbose_name=_("Short description"), )
    full_description = HTMLFieldTinyMCE( blank=True, null=True, verbose_name=_("Full description"),)
    #ForeignKey Relationship
    table_description = HTMLFieldTinyMCE( blank=True, null=True, verbose_name=_("table description"),)
    prod_categories = models.ManyToManyField( "ProductCategory" , blank=True, null=True, related_name="products", verbose_name=_("Product Categories"),)

    related_products = models.ManyToManyField( 'self', blank=True, null=True, symmetrical=False, related_name='%(class)s_related_categories', verbose_name = _('Related Products'), )

    max_temp = models.CharField( blank=True, null=True, max_length=150, verbose_name=_("Max Temperature"), )
    hints =  models.TextField( blank=True, null=True, verbose_name=_("Hints"),)

    class Meta(object):
        abstract = False
        app_label = 'jumbo_product'
        verbose_name = _('Product')
        verbose_name_plural = _('Products')

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        url = reverse('product_detail', args=[self.slug])
        return url

    def hints_as_list(self):
        if self.hints:return self.hints.split('\r\n')
        return []

    def hints_list_lenght(self):
        return len( self.hints_as_list() )

    def is_main_category(self):
        categories = self.prod_categories.all().values_list('name',flat=True)
        for cat in categories:
            if cat in ['Accessorio', 'Ricambio']: return False
        return True
#
# def save(self, *args, **kwargs):
#        """Overridden model save function which supports the polymorphism
#        functionality (through pre_save_polymorphic)."""
#        #self.pre_save_polymorphic()
#        self.save()
#        return super(Product, self).save(*args, **kwargs)

class ProductTranslation(TranslationModel):

    parent = models.ForeignKey( Product, db_index = True, related_name = 'translations', verbose_name = _('parent'), )
    name   = models.CharField(  max_length = 100, verbose_name = _('Name'), )
    short_description = models.CharField( blank=True, null=True, max_length=150, verbose_name=_("Short description"), )
    full_description  = HTMLFieldTinyMCE( null = True, blank = True, verbose_name = _('Full Description'), )
    hints =  models.TextField( blank=True, null=True, verbose_name=_("Hints"),)

    class Meta:
        app_label = 'jumbo_product'
        verbose_name = _('Product Translation')
        verbose_name_plural = _('Product Translations')
        unique_together = (('parent','language',),)

    def __unicode__(self):
        return u'%s' % self.name[:15]

class ProductGalleryImage(DateModel, UserModel, StatusModel, OrderedModel):

    product = models.ForeignKey(Product, related_name="images", blank=True, null=True)
    title = models.CharField(max_length=255)
    image = FilerImageField()

    class Meta(object):
        abstract = False
        app_label = 'jumbo_product'
        verbose_name = _('Products Image')
        verbose_name_plural = _('Products Images')

    def save(self, *args, **kwargs):
        if not self.pk:
            self.date_create = self.image.date_taken
        super(ProductGalleryImage, self).save(*args, **kwargs)

    def __unicode__(self):
        return self.title
