from django.core.urlresolvers import reverse
from django.db import models
from filer.fields.image import FilerImageField
from jumbo.db.models import HTMLField
try: from jumbo.db.models import HTMLFieldTinyMCE
except : pass
from django.template.defaultfilters import slugify
from django.utils.translation import ugettext_lazy as _

from jumbo.middleware.thread_local import get_request, get_current_user
from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jumbo_i18n.models import TranslationModel

import mptt
from mptt.models import MPTTModel, TreeForeignKey

##################################
# CATEGORIA CATALOGO             #
##################################

class ProductCategoryAbstract( DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField( db_index=True, max_length = 200, verbose_name = _("Name"),)
    slug = models.SlugField( db_index=True, blank= True, null= True, max_length = 200, verbose_name = _("Slug"),
                             help_text = _("Used for URLs, auto-generated from name if blank"),)
    code = models.CharField( db_index=True, blank= True, null= True, max_length = 20, verbose_name = _("Code"),)

    description      = HTMLFieldTinyMCE( blank= True, null= True, verbose_name = _("Description"), help_text = _("Description"),)
    long_description = HTMLFieldTinyMCE( blank= True, null= True, verbose_name = _("Long description"),
                                  help_text = _("Long description"),)
    #Relations
#    related_categories = models.ManyToManyField( 'self', symmetrical = False, blank= True, null= True,
#                                                 related_name = '%(class)s_related_shop_categories',
#                                                 verbose_name = _('Related Shop Categories'),)
    #parent = TreeForeignKey('self', null=True, blank=True, related_name='children')

    class Meta:
        abstract = True
        app_label = 'jumbo_product'
        #ordering = ['tree_id', 'level', 'ordering']
        verbose_name = _("Product Category")
        verbose_name_plural = _("Product Categories")

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return self.name


class ProductCategory(ProductCategoryAbstract):

    image = FilerImageField(blank=True, null=True)

    class Meta:
        db_table= 'jumbo_product_productcategory'
        abstract = False
        app_label = 'jumbo_product'
        #ordering = ['tree_id', 'level', 'ordering']
        verbose_name = _("Product Category")
        verbose_name_plural = _("Product Categories")

    def get_absolute_url(self):
        return reverse('product_cat_detail',args=[self.slug])

TreeForeignKey(ProductCategory, blank=True, null=True).contribute_to_class(ProductCategory, 'parent')
mptt.register(ProductCategory, order_insertion_by=['name'])