__author__ = 'dario'
# -*- coding: utf-8 -*-
from django import template

from classytags.helpers import InclusionTag, Tag
from classytags.core import Options
from classytags.arguments import Argument

from ..models import Product , ProductCategory

register = template.Library()

class CategoryProductsOverview(InclusionTag):
    """
    Inclusion tag for displaying all products.
    """
    name = 'category_products_overview'
    template = 'jumbo_product/templatetags/category_overview.html'
    options = Options(
        Argument('objects', resolve=True, required=False),
    )

    def get_context(self, context, objects):
        if objects is None:
            objects =  ProductCategory.objects.filter(status=True)
        context.update({'categories': objects, })
        return context

register.tag(CategoryProductsOverview)


class CategoryProductsLink(InclusionTag):
    """
    Inclusion tag for displaying simple list links <li> of category by one tree.
    """
    name = 'category_link_list'
    template = 'jumbo_product/templatetags/category_link_list.html'
    options = Options(
        Argument('num', resolve=True, required=False ),
        Argument('tree', resolve=True, required=False ),
        Argument('linktype', resolve=True, required=False, default= False ),
        Argument('title', resolve=True, required=False, default= True ),
    )

    def get_context(self, context, num, tree, linktype , title):
        if num is not None and num != 0:
            objects =  ProductCategory.objects.filter(status=True)[:int(num)]#
        else:
            objects =  ProductCategory.objects.filter(status=True)#
        return  {'categories': objects, 'linktype': linktype, 'title':int(title),
                 'request': context.get('request', False) }

register.tag(CategoryProductsLink)

#example from documentation
class Hello(Tag):
    name = 'hello'
    options = Options(
        Argument('name'),
        'as',
        Argument('varname', required=False, resolve=False)
    )

    def render_tag(self, context, name, varname):
        output = 'hello %s' % name
        if varname:
            context[varname] = output
            return ''
        else:
            return output

register.tag(Hello)
