from .models import Product , ProductCategory
from django.views.generic import (TemplateView, ListView, DetailView, View)
from django.views.generic.base import TemplateResponseMixin# Create your views here.

class JProductTemplateView(TemplateView):
    """
    A class-based view for use within the shop (this allows to keep the above
    import magic in only one place)

    As defined by
    http://docs.djangoproject.com/en/dev/topics/class-based-views/

    Stuff defined here (A.K.A this is a documentation proxy for the above
    link):
    ---------------------------------------------------------------------
    self.template_name : Name of the template to use for rendering
    self.get_context_data(): Returns the context {} to render the template with
    self.get(request, *args, **kwargs): called for GET methods
    """


class JProductListView(ListView):
    """
    This is just to abstract the "Django version switching magic happening up
    there
    """
    excl_cat = ['Ricambio','Accessorio']
    queryset = Product.objects.filter(status=1).exclude(prod_categories__name__in=excl_cat).order_by('name')
    template_name = "jumbo_product/product/product_list.html"


class JProductADetailView(DetailView):
    """
    This is just to abstract the "Django version switching magic happening up
    there
    """


class JProductView(View):
    """
    An abstraction of the basic view
    """


class JProductTemplateResponseMixin(TemplateResponseMixin):
    """
    An abstraction to solve the import problem for the template response mixin
    """

class JProductDetailView(JProductADetailView):
    """
    This view handles displaying the right template for the subclasses of
    Product.
    It will look for a template at the normal (conventional) place, but will
    fallback to using the default product template in case no template is
    found for the subclass.
    """
    model = Product  # It must be the biggest ancestor of the inheritence tree.
    generic_template = 'jumbo_product/product/product_detail.html'

    def get_template_names(self):
        ret = super(JProductDetailView, self).get_template_names()
        if not self.generic_template in ret:
            ret.append(self.generic_template)
        return ret

class JProductCatDetailView(JProductADetailView):
    """
    This view handles displaying the right template for the subclasses of
    Product.
    It will look for a template at the normal (conventional) place, but will
    fallback to using the default product template in case no template is
    found for the subclass.
    """
    model = ProductCategory  # It must be the biggest ancestor of the inheritence tree.
    generic_template = 'jumbo_product/product/product_cat_detail.html'

    def get_template_names(self):
        ret = super(JProductCatDetailView, self).get_template_names()
        if not self.generic_template in ret:
            ret.append(self.generic_template)
        return ret